# -*- coding utf-8 -*-
# authors: Ethosa, Konard

import re

class Translator:
    def __init__(self, codeString="", rules=[]):
        """initialize class
        
        Keyword Arguments:
            codeString {str} -- source code on C# (default: {""})
            rules {list} -- include your own rules (default: {[]})
        """
        self.codeString = codeString
        self.rules = rules
        self.Transform = self.compile = self.translate # callable objects

    def translate(self, src=None):
        """translate source code on C# to C++
        
        Keyword Arguments:
            src {str} -- [source code on C#] (default: {None})
        
        Returns:
            str -- Translated code on C++
        """
        if src: # check src argument
            current = src[:] # copy string
        else:
            current = self.codeString[:]

        for i in self.rules:
            matchPattern = i[0]
            substitutionPattern = i[1]
            pathPattern = i[2]
            maximumRepeatCount = i[3]
            if pathPattern == None: # or pathPattern.IsMatch(context.Path)
                replaceCount = 0
                current = re.sub(matchPattern, substitutionPattern, current)
                while re.search(matchPattern, current):
                    if replaceCount+1 > maximumRepeatCount:
                        break
                    replaceCount += 1
                    current = re.sub(matchPattern, substitutionPattern, current)
        return current

    def addLine(self, string=""):
        """add a new line in codeString variable
        
        Keyword Arguments:
            string {str} -- line without "\n" (default: {""})
        """
        self.codeString += "\n%s" % (string)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="retranslator",
    version="0.0.5",
    author="Ethosa",
    author_email="social.ethosa@gmail.com",
    description="retranslator",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/linksplatform/RegularExpressions.Transformer/tree/master/python",
    packages=setuptools.find_packages(),
    license="LGPLv3",
    keywords="csharp cpp cs2cpp platform ethosa konard retranslator",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Operating System :: OS Independent",
    ],
    project_urls={
        "Github" : "https://github.com/linksplatform/RegularExpressions.Transformer/tree/master/python",
        "Documentation" : "https://github.com/linksplatform/RegularExpressions.Transformer/tree/master/python",
    },
    python_requires=">=3",
    install_requires=[]
)